==> haskell-void-0.7.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-void.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 void
version:              0.7.3
visibility:           public
id:                   void-0.7.3-FrIAx1z4E4J2j5pUfTWP2p
key:                  void-0.7.3-FrIAx1z4E4J2j5pUfTWP2p
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            portable
homepage:             http://github.com/ekmett/void
synopsis:             A Haskell 98 logically uninhabited data type
description:
    A Haskell 98 logically uninhabited data type, used to indicate that a given term should not exist.

category:             Data Structures
abi:                  ec5f8fb531a1adcd2844004d437f2b91
exposed:              True
exposed-modules:      Data.Void.Unsafe
import-dirs:          /usr/lib/ghc-8.8.3/site-local/void-0.7.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/void-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/void-0.7.3
hs-libraries:         HSvoid-0.7.3-FrIAx1z4E4J2j5pUfTWP2p
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-void/html/void.haddock
haddock-html:         /usr/share/doc/haskell-void/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-void-0.7.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-void.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 void
version:              0.7.3
visibility:           public
id:                   void-0.7.3-7Pw6De9DEFWGgZnJBlu5U9
key:                  void-0.7.3-7Pw6De9DEFWGgZnJBlu5U9
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            portable
homepage:             http://github.com/ekmett/void
synopsis:             A Haskell 98 logically uninhabited data type
description:
    A Haskell 98 logically uninhabited data type, used to indicate that a given term should not exist.

category:             Data Structures
abi:                  64d0b6a7050964f84a946a90b4a0f249
exposed:              True
exposed-modules:      Data.Void.Unsafe
import-dirs:          /usr/lib/ghc-8.10.1/site-local/void-0.7.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/void-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/void-0.7.3
hs-libraries:         HSvoid-0.7.3-7Pw6De9DEFWGgZnJBlu5U9
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-void/html/void.haddock
haddock-html:         /usr/share/doc/haskell-void/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
